# Django Carpet 0.1.13

This package contains the base function and classes for a Django project

```text
Note: This package requires python 3.11 and higher
```

## Installation
```text
pip install django-carpet
```

## Import
```python

```
